@@ -47,7 +47,7 @@ use English; require Exporter;
 # Return library locations
 
 
-sub PDL_INCLUDE { '-I'.whereami_any().'/Core' };
+sub PDL_INCLUDE { '"-I'.whereami_any().'/Core"' };
 sub PDL_TYPEMAP { whereami_any().'/Core/typemap.pdl' };
 # sub PDL_INST_INCLUDE { '-I'.whereami_any().'/Core' };
 # sub PDL_INST_TYPEMAP { whereami_any().'/Core/typemap.pdl' };
@@ -339,50 +339,22 @@ sub flushgeneric {  # Construct the generic code switch
 # Standard PDL postamble
 
 sub postamble {
-
-  if ($^O =~ /win32/i) {
-    open FI,'>./getdev.pl' or die "couldn't open getdev.pl: $!";
-    my $location = whereami_any();
-    print FI << "EOD";
-
-  require \"$location/Core/Dev.pm\";
-  PDL::Core::Dev->import();				\
-  genpp();
-  1;
-EOD
-     close FI;
-     return q~
+  my ($self) = @_;
+  require ExtUtils::MM;
+  my $MM = bless { NAME => 'Fake' }, 'MM';
+  my $devpm = whereami_any()."/Core/Dev.pm";
+  my $oneliner = sprintf $MM->oneliner(<<'EOF'), $devpm;
+require "%s"; PDL::Core::Dev->import(); genpp();
+EOF
+  sprintf <<'EOF', $oneliner;
 
 # Rules for the generic preprocessor
 
 .SUFFIXES: .g
 .g.c:
-	$(PERL) -e "require './getdev.pl'" $<  > $@
-
-.c$(OBJ_EXT):
-	$(CCCMD) $(CCCDLFLAGS) -I$(PERL_INC) $(DEFINE) $*.c
-
-     ~;
-} else {
-
-q~
-
-# Rules for the generic preprocessor
-
-.SUFFIXES: .g
-.g.c:
-	$(PERL) -e 'require "~.whereami_any().q~/Core/Dev.pm"; \
-		PDL::Core::Dev->import();				\
-		genpp()' $<  > $@
-
-.g$(OBJ_EXT):
-	$(PERL) -e 'require "~.whereami_any().q~/Core/Dev.pm"; \
-		PDL::Core::Dev->import();				\
-		genpp()' $<  > $*.c
-	$(CCCMD) $(CCCDLFLAGS) -I$(PERL_INC) $(DEFINE) $*.c
-
-~;}
+	%s "$<" > "$@"
 
+EOF
 }
 
 # Expects list in format:
@@ -398,8 +370,9 @@ sub pdlpp_postamble_int {
 	join '',map { my($src,$pref,$mod) = @$_;
 	my $w = whereami_any();
 	$w =~ s%/((PDL)|(Basic))$%%;  # remove the trailing subdir
-	my $core = "$w/Basic/Core";
-	my $gen = "$w/Basic/Gen";
+	my $basic = File::Spec->abs2rel(File::Spec->catdir($w, 'Basic'));
+	my $core = File::Spec->catdir($basic, 'Core');
+	my $gen = File::Spec->catdir($basic, 'Gen');
 
 ## I diked out a "$gen/pm_to_blib" dependency (between $core/badsupport.p and
 # $core/Types.pm below), because it appears to be causing excessive recompiles.
@@ -411,7 +384,7 @@ sub pdlpp_postamble_int {
 qq|
 
 $pref.pm: $src $core/badsupport.p $core/Types.pm
-	\$(PERL) -I$w/blib/lib -I$w/blib/arch \"-MPDL::PP qw/$mod $mod $pref/\" $src
+	\$(PERLRUNINST) \"-MPDL::PP qw/$mod $mod $pref/\" $src
 
 $pref.xs: $pref.pm
 	\$(TOUCH) \$@
@@ -548,51 +521,12 @@ sub unsupported {
 }
 
 sub write_dummy_make {
-  require IO::File;
-    my ($msg) = @_;
-    print STDERR "writing dummy Makefile\n";
-    my $fh = new IO::File "> Makefile" or die "Can't open dummy Makefile: $!";
-
-if($^O !~ /mswin32/i) {
-    print $fh <<"EOT";
-fred:
-	\@echo \"****\"
-	\@echo \"$msg\"
-	\@echo \"****\"
-
-all: fred
-
-test: fred
-
-clean ::
-	-mv Makefile Makefile.old
-
-realclean ::
-	rm -rf Makefile Makefile.old
-
-EOT
-}
-
-else { # It's Win32
-    print $fh <<"EOT";
-fred:
-	\@echo \"****\"
-	\@echo \"$msg\"
-	\@echo \"****\"
-
-all: fred
-
-test: fred
-
-clean ::
-	-ren Makefile Makefile.old <NUL
-
-realclean ::
-	del /F /Q Makefile Makefile.old <NUL
-
-EOT
-}
-   close($fh) or die "Can't close dummy Makefile: $!";
+  my ($msg) = @_;
+  $msg =~ s#\n*\z#\n#;
+  $msg =~ s#^\s*#\n#gm;
+  print $msg;
+  require ExtUtils::MakeMaker;
+  ExtUtils::MakeMaker::WriteEmptyMakefile(NAME => 'Dummy', DIR => []);
 }
 
 sub getcyglib {
